# Common function to operate with Microsoft Video Indexer

### To get a Microsoft Video Indexer access token
```
from video_indexer import get_access_token

token = get_access_token(VI_SUBSCRIPTION_KEY, VI_LOCATION, VI_ACCOUNT_ID)
```